Package: deepSTRAPP
Title: Test for Differences in Diversification Rates over Time
Version: 1.0.0
Authors@R: c(
    person("Maël", "Doré", , email = "mael.dore@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0003-3242-9242")),
    person("Dan", "Rabosky", role = "ctb"),
    person("Mike", "Grundler", role = "ctb"),
    person("Huateng", "Huang", role = "ctb"),
    person("Pascal", "Title", role = "ctb"),
    person("Liam", "Revell", role = "ctb"),
    person("Nicholas J.", "Matzke", role = "ctb"))
Description: Employ time-calibrated phylogenies and trait/range data to test for
    differences in diversification rates over evolutionary time.  Extend
    the STRAPP test from BAMMtools::traitDependentBAMM() to any time step
    along phylogenies. See inst/COPYRIGHTS for details on third-party code.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
URL: https://github.com/MaelDore/deepSTRAPP,
        https://maeldore.github.io/deepSTRAPP/
BugReports: https://github.com/MaelDore/deepSTRAPP/issues
Imports: ape (>= 5.8.0), BAMMtools (>= 2.1.12), cladoRcpp (>= 0.15.1),
        coda (>= 0.19-4.1), cowplot (>= 1.1.3), dplyr (>= 1.1.4),
        dunn.test (>= 1.3.6), geiger (>= 2.0.11), ggplot2 (>= 3.5.0),
        methods (>= 4.4.2), phytools (>= 2.0.0), plyr (>= 1.8.9), purrr
        (>= 1.0.2), qpdf (>= 1.4.1), RColorBrewer (>= 1.1-3), Rcpp (>=
        1.0.14), scales (>= 1.3.0), stringr (>= 1.5.1), tidyr (>=
        1.3.1)
Depends: R (>= 4.4)
LazyData: true
LazyDataCompression: xz
Suggests: knitr, maps (>= 3.4.2), parallel (>= 4.4.2), BioGeoBEARS (>=
        1.1.3), rmarkdown
Additional_repositories: https://maeldore.github.io/drat
LinkingTo: Rcpp
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2026-01-13 16:22:36 UTC; Mael
Author: Maël Doré [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-3242-9242>),
  Dan Rabosky [ctb],
  Mike Grundler [ctb],
  Huateng Huang [ctb],
  Pascal Title [ctb],
  Liam Revell [ctb],
  Nicholas J. Matzke [ctb]
Maintainer: Maël Doré <mael.dore@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-19 17:30:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-29 15:25:20 UTC; unix
Archs: deepSTRAPP.so.dSYM
