# Generated by roxygen2: do not edit by hand

export(BSM_to_phytools_simmap)
export(compute_STRAPP_test_for_focal_time)
export(cut_contMap_for_focal_time)
export(cut_densityMap_for_focal_time)
export(cut_densityMaps_for_focal_time)
export(cut_phylo_for_focal_time)
export(extract_diversification_data_melted_df_for_focal_time)
export(extract_most_likely_ranges_from_densityMaps_for_focal_time)
export(extract_most_likely_states_from_densityMaps_for_focal_time)
export(extract_most_likely_trait_values_for_focal_time)
export(extract_most_likely_trait_values_from_contMap_for_focal_time)
export(is_dev_version)
export(plot_BAMM_rates)
export(plot_STRAPP_pvalues_over_time)
export(plot_contMap)
export(plot_densityMaps_overlay)
export(plot_histogram_STRAPP_test_for_focal_time)
export(plot_histograms_STRAPP_tests_over_time)
export(plot_rates_through_time)
export(plot_rates_vs_trait_data_for_focal_time)
export(plot_rates_vs_trait_data_over_time)
export(plot_traits_vs_rates_on_phylogeny_for_focal_time)
export(plot_traits_vs_rates_on_phylogeny_over_time)
export(prepare_diversification_data)
export(prepare_trait_data)
export(run_deepSTRAPP_for_focal_time)
export(run_deepSTRAPP_over_time)
export(select_best_model_from_BioGeoBEARS)
export(select_best_trait_model_from_geiger)
export(update_rates_and_regimes_for_focal_time)
importFrom(BAMMtools,addBAMMshifts)
importFrom(BAMMtools,dtRates)
importFrom(BAMMtools,getEventData)
importFrom(BAMMtools,getShiftNodesFromIndex)
importFrom(BAMMtools,maximumShiftCredibility)
importFrom(BAMMtools,plot.bammdata)
importFrom(BAMMtools,plotPrior)
importFrom(BAMMtools,samplingProbs)
importFrom(BAMMtools,setBAMMpriors)
importFrom(BAMMtools,subsetEventData)
importFrom(RColorBrewer,brewer.pal)
importFrom(Rcpp,evalCpp)
importFrom(ape,.PlotPhyloEnv)
importFrom(ape,all.equal.phylo)
importFrom(ape,as.phylo)
importFrom(ape,branching.times)
importFrom(ape,edgelabels)
importFrom(ape,extract.clade)
importFrom(ape,nodelabels)
importFrom(ape,write.tree)
importFrom(cladoRcpp,rcpp_areas_list_to_states_list)
importFrom(coda,effectiveSize)
importFrom(cowplot,plot_grid)
importFrom(cowplot,save_plot)
importFrom(dplyr,arrange)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,join_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,reframe)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(dunn.test,dunn.test)
importFrom(geiger,fitContinuous)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,annotation_custom)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_color_brewer)
importFrom(ggplot2,scale_color_discrete)
importFrom(ggplot2,scale_color_gradientn)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_brewer)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,unit)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,gray)
importFrom(grDevices,hsv)
importFrom(grDevices,pdf)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(grDevices,rgb2hsv)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(grid,gpar)
importFrom(grid,textGrob)
importFrom(methods,hasArg)
importFrom(phytools,add.simmap.legend)
importFrom(phytools,aic.w)
importFrom(phytools,as.Qmatrix)
importFrom(phytools,contMap)
importFrom(phytools,densityMap)
importFrom(phytools,fastAnc)
importFrom(phytools,getDescendants)
importFrom(phytools,nodeHeights)
importFrom(phytools,plot.contMap)
importFrom(phytools,plot.densityMap)
importFrom(phytools,rescale)
importFrom(phytools,rescaleSimmap)
importFrom(phytools,setMap)
importFrom(plyr,ldply)
importFrom(qpdf,pdf_combine)
importFrom(scales,hue_pal)
importFrom(stats,complete.cases)
importFrom(stats,cor.test)
importFrom(stats,kruskal.test)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,wilcox.test)
importFrom(stringr,str_detect)
importFrom(stringr,str_remove)
importFrom(stringr,str_to_title)
importFrom(tidyr,pivot_longer)
importFrom(utils,capture.output)
importFrom(utils,data)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
useDynLib(deepSTRAPP)
